@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CUSTOMTOOLSVIEWINTERFACE_H
-#define CUSTOMTOOLSVIEWINTERFACE_H
+#pragma once
 
 #include "pimcommon_export.h"
 
@@ -31,6 +30,6 @@ Q_SIGNALS:
     void insertText(const QString &text);
     void toolsWasClosed();
     void activateView(QWidget *);
+    void configure(QWidget *parent);
 };
 }
-#endif // CUSTOMTOOLSVIEWINTERFACE_H
